"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hydratePopulated = exports.populatingLookupQuery = exports.populatingLookupPreserveNullQuery = void 0;
const mongoose_1 = __importDefault(require("mongoose"));
const populatingLookupPreserveNullQuery = (collectionName, fieldName, foreignFieldName = '_id') => {
    return [
        {
            $lookup: {
                from: collectionName,
                let: { [fieldName]: `$${fieldName}` },
                pipeline: [
                    {
                        $match: {
                            $expr: {
                                $eq: [`$${foreignFieldName}`, `$$${fieldName}`]
                            }
                        }
                    }
                ],
                as: fieldName
            }
        },
        { $unwind: { path: `$${fieldName}`, preserveNullAndEmptyArrays: true } }
    ];
};
exports.populatingLookupPreserveNullQuery = populatingLookupPreserveNullQuery;
const populatingLookupQuery = (collectionName, fieldName, foreignFieldName = '_id') => {
    return [
        {
            $lookup: {
                from: collectionName,
                localField: fieldName,
                foreignField: foreignFieldName,
                as: fieldName
            }
        },
        { $unwind: { path: `$${fieldName}` } }
    ];
};
exports.populatingLookupQuery = populatingLookupQuery;
const hydratePopulated = (model, json, populated) => {
    const document = model.hydrate(json);
    for (const path of populated) {
        if (!json[path]) {
            continue;
        }
        const options = model.schema.paths[path]?.options;
        if (!options?.ref) {
            continue;
        }
        document[path] = mongoose_1.default.model(options.ref).hydrate(json[path]);
    }
    return document;
};
exports.hydratePopulated = hydratePopulated;
//# sourceMappingURL=index.js.map